@@ -1,6 +1,6 @@
 /*
  * ****************************************************************************
- * Copyright (c) 2013-2022, PyInstaller Development Team.
+ * Copyright (c) 2013-2023, PyInstaller Development Team.
  *
  * Distributed under the terms of the GNU General Public License (version 2
  * or later) with exception for distributing the bootloader.
@@ -513,15 +513,15 @@ pyi_pylib_start_python(ARCHIVE_STATUS *status)
         return -1;
     }
     VS("LOADER: Pre-init sys.path is %s\n", pypath);
-#ifdef _WIN32
-    // Call GetPath first, so the static dllpath will be set as a side
-    // effect. Workaround for http://bugs.python.org/issue29778, see #2496.
-    // Due to another bug calling this on non-win32 with Python 3.6 causes
-    // memory corruption, see #2812 and
-    // https://bugs.python.org/issue31532. But the workaround is only
-    // needed for win32.
+
+    /*
+     * Call Py_GetPath() first. This used be necessary on Windows to
+     * work around https://bugs.python.org/issue29778, but it also seems
+     * necessary on other platforms with python 3.8 and 3.9 when python's
+     * memory debugging and validation is enabled (PYTHONMALLOC=debug or
+     * PYTHONDEVMODE=1).
+     */
     PI_Py_GetPath();
-#endif
     PI_Py_SetPath(pypath_w);
 
     /* Start python. */
