@@ -13,10 +13,68 @@ import os
 
 import pytest
 
+from PyInstaller import compat
+
 # Directory with testing modules used in some tests.
 _MODULES_DIR = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'modules')
 
 
+# Test that in python 3.11 and later, sys._stdlib_dir is set and that python-frozen modules have __file__ attribute.
+@pytest.mark.skipif(not compat.is_py311, reason="applicable only to python >= 3.11")
+def test_frozen_stdlib_modules(pyi_builder, script_dir, tmpdir):
+    test_script = 'pyi_frozen_stdlib_modules.py'
+    ref_result_file = os.path.join(tmpdir, 'ref_results.txt')
+    result_file = os.path.join(tmpdir, 'results.txt')
+
+    # Run the test script unfrozen, to obtain reference results
+    ret = compat.exec_python_rc(
+        os.path.join(script_dir, test_script),
+        ref_result_file,
+    )
+    assert ret == 0, "Unfrozen test script failed!"
+
+    # Freeze and run the test script
+    pyi_builder.test_script(
+        test_script,
+        app_args=[result_file],
+    )
+
+    # Process the results
+    def _normalize_module_path(module_path, stdlib_dir):
+        if not module_path:
+            return module_path
+        module_path, ext = os.path.splitext(os.path.relpath(module_path, stdlib_dir))
+        assert ext in ('.pyc', '.py')
+        return module_path
+
+    def _load_results(filename):
+        # Read pprint-ed results
+        with open(filename, 'r') as fp:
+            data = fp.read()
+        data = eval(data)
+
+        # First entry is sys._stdlib_dir
+        stdlib_dir = data[0]
+
+        results = []
+        for name, file_attr, state_filename, state_origname in data[1:]:
+            # Remove sys._stdlib_dir prefix from __file__ attribute and filename from __spec__.loader_state, and remove
+            # the .py/.pyc suffix for easier comparison.
+            results.append((
+                name,
+                _normalize_module_path(file_attr, stdlib_dir),
+                _normalize_module_path(state_filename, stdlib_dir),
+                state_origname,
+            ))
+
+        return results
+
+    ref_results = _load_results(ref_result_file)
+    results = _load_results(result_file)
+
+    assert results == ref_results
+
+
 # Test inspect.getmodule() on stack-frames obtained by inspect.stack(). Reproduces the issue reported by #5963 while
 # expanding the test to cover a package and its submodule in addition to the __main__ module.
 def test_inspect_getmodule_from_stackframes(pyi_builder):
@@ -182,3 +240,43 @@ def test_program_importing_module_with_invalid_encoding2(pyi_builder):
         """,
         pyi_args=['--paths', extra_path]
     )
+
+
+# Test the robustness of `inspect` run-time hook w.r.t. to the issue #7642.
+#
+# If our run-time hook imports a module in the global namespace and attempts to use this module in a function that
+# might get called later on in the program (e.g., a function override or registered callback function), we are at the
+# mercy of user's program, which might re-bind the module's name to something else (variable, function), leading to
+# an error.
+#
+# This particular test will raise:
+# ```
+# Traceback (most recent call last):
+#  File "test_source.py", line 17, in <module>
+#  File "test_source.py", line 14, in some_interactive_debugger_function
+#  File "inspect.py", line 1755, in stack
+#  File "inspect.py", line 1730, in getouterframes
+#  File "inspect.py", line 1688, in getframeinfo
+#  File "PyInstaller/hooks/rthooks/pyi_rth_inspect.py", line 22, in _pyi_getsourcefile
+# AttributeError: 'function' object has no attribute 'getfile'
+# ```
+def test_inspect_rthook_robustness(pyi_builder):
+    pyi_builder.test_source(
+        """
+        # A custom function in global namespace that happens to have name clash with `inspect` module.
+        def inspect(something):
+            print(f"Inspecting {something}: type is {type(something)}")
+
+
+        # A call to `inspect.stack` function somewhere deep in an interactive debugger framework.
+        # This eventually ends up calling our `_pyi_getsourcefile` override in the `inspect` run-time hook. The
+        # override calls `inspect.getfile`; if the run-time hook imported `inspect` in a global namespace, the
+        # name at this point is bound the the custom function that program defined, leading to an error.
+        def some_interactive_debugger_function():
+            import inspect
+            print(f"Current stack: {inspect.stack()}")
+
+
+        some_interactive_debugger_function()
+        """
+    )
